==> wordpress-0.0.6.tgz: package/gitignore/test.js <==
var wordpress = require( "../lib/wordpress" );

var client = wordpress.createClient({
	url: "https://localhost",
	username: "admin",
	password: "admin"
});

// client.newPost({
// 	content: "öö"
// }, function() {});

client.newPost({
	title: "Pager New",
	content: "even moar page",
	type: "page",
	parent: 2,
	status: "publish"
}, function() {
	console.log( arguments );
});

// client.newPost({
// 	title: "Post with auto terms",
// 	content: "got terms?",
// 	terms_names: {
// 		post_tag: [ "foo", "bar" ]
// 	}
// }, function() {
// 	console.log( arguments );
// });

// client.editPost( 20, {
// 	title: "Up Page"
// }, function() {
// 	console.log( arguments );
// });

// client.deletePost( 20, function() {
// 	console.log( arguments );
// });

// client.getPost( 2,
// 	[ "customFields", "name" ],
// function( error, post ) {
// 	console.log( error );
// 	console.log( post );
// });

// client.editPost( 32, {
// 	termNames: {
// 		// post_tag: [ 4, 5 ],
// 		category: [ "myothercat" ],
// 	},
// 	customFields: [
// 		{
// 			id: "27"
// 			// key: "afoo",
// 			// value: "abar"
// 		}
// 	]
// }, function() {
// 	console.log( arguments );
// });

// client.getTaxonomy( "category", function( error, taxonomy ) {
// 	console.log( error );
// 	console.log( taxonomy );
// });

// client.getTaxonomies(function( error, taxonomies ) {
// 	// console.log( arguments );
// 	taxonomies.forEach(function( taxonomy ) {
// 		console.log( taxonomy.name );
// 	});
// });

// client.getTerm( "category", 6, function( error, term ) {
// 	console.log( error );
// 	console.log( term );
// });

// client.getTerms( "category",
// // {
// // 	hideEmpty: true
// // },
// function( error, categories ) {
// 	console.log( error );
// 	console.log( categories );
// });

// client.newTerm({
// 	name: "amazing term",
// 	taxonomy: "category"
// }, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.editTerm( 8, {
// 	taxonomy: "category",
// 	slug: "derp"
// }, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.deleteTerm( "category", 8, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.getPosts({
// 	type: "page",
// 	orderby: "post_date",
// 	order: "ASC"
// },
// [ "content", "name" ],
// function() {
// 	console.log( arguments );
// });

// client.getPostType( "page", function( error, postType ) {
// 	console.log( error );
// 	console.log( postType );
// });

// client.getPosts( "any", function() {
// 	console.log( arguments );
// });

// client.getPostTypes(function( error, postTypes ) {
// 	console.log( error );
// 	console.log( postTypes );
// });


// client.call( "system.listMethods", function() {
// 	console.log( arguments );
// });

// client.call( "gw.getPostPaths", function() {
// 	console.log( arguments );
// });

==> wordpress-0.1.0.tgz: package/gitignore/test.js <==
var wordpress = require( "../lib/wordpress" );

var client = wordpress.createClient({
	url: "wordpress.local",
	username: "admin",
	password: "admin"
});



// client.newPost({
// 	content: "öö"
// }, function() {});

// client.newPost({
// 	title: "Pager New",
// 	content: "even moar page",
// 	type: "page",
// 	parent: 2,
// 	status: "publish"
// }, function() {
// 	console.log( arguments );
// });

// client.newPost({
// 	title: "Post with auto terms",
// 	content: "got terms?",
// 	terms_names: {
// 		post_tag: [ "foo", "bar" ]
// 	}
// }, function() {
// 	console.log( arguments );
// });

// client.editPost( 20, {
// 	title: "Up Page"
// }, function() {
// 	console.log( arguments );
// });

// client.deletePost( 20, function() {
// 	console.log( arguments );
// });

// client.getPost( 2,
// 	[ "customFields", "name" ],
// function( error, post ) {
// 	console.log( error );
// 	console.log( post );
// });

// client.editPost( 32, {
// 	termNames: {
// 		// post_tag: [ 4, 5 ],
// 		category: [ "myothercat" ],
// 	},
// 	customFields: [
// 		{
// 			id: "27"
// 			// key: "afoo",
// 			// value: "abar"
// 		}
// 	]
// }, function() {
// 	console.log( arguments );
// });

// client.getTaxonomy( "category", function( error, taxonomy ) {
// 	console.log( error );
// 	console.log( taxonomy );
// });

// client.getTaxonomies(function( error, taxonomies ) {
// 	// console.log( arguments );
// 	taxonomies.forEach(function( taxonomy ) {
// 		console.log( taxonomy.name );
// 	});
// });

// client.getTerm( "category", 6, function( error, term ) {
// 	console.log( error );
// 	console.log( term );
// });

// client.getTerms( "category",
// {
// 	orderby: "termId"
// },
// // {
// // 	hideEmpty: true
// // },
// function( error, categories ) {
// 	console.log( error );
// 	categories.forEach(function( category ) {
// 		console.log( category.termId, category.slug, category.name );
// 	});
// });

// client.newTerm({
// 	name: "amazing term",
// 	taxonomy: "category"
// }, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.editTerm( 8, {
// 	taxonomy: "category",
// 	slug: "derp"
// }, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.deleteTerm( "category", 8, function( error, data ) {
// 	console.log( error );
// 	console.log( data );
// });

// client.getPosts({
// 	type: "post",
// 	orderby: "date",
// 	order: "ASC"
// },
// [ "content", "name", "date" ],
// function( error, posts ) {
// 	console.log( error );
// 	posts.forEach(function( post ) {
// 		console.log( post.date, post.name );
// 	});
// });

// client.getPostType( "page", function( error, postType ) {
// 	console.log( error );
// 	console.log( postType );
// });

// client.getPosts( "any", function() {
// 	console.log( arguments );
// });

// client.getPostTypes(function( error, postTypes ) {
// 	console.log( error );
// 	console.log( postTypes );
// });


// client.call( "system.listMethods", function() {
// 	console.log( arguments );
// });

// client.listMethods(function() {
// 	console.log( arguments );
// });

// client.call( "demo.addTwoNumbers", 2, 3, function() {
// 	console.log( arguments );
// });

// client.call( "gw.getPostPaths", "any", function() {
// 	console.log( arguments );
// });



client.authenticatedCall( "gw.addResource", "hanoi.jpg", require( "fs" ).readFileSync( "hanoi.jpg", "base64" ), function() {
	console.log( arguments );
});

// client.authenticatedCall( "gw.deleteResource", "test.js", function() {
// 	console.log( arguments );
// });

// client.call( "gw.getResources", function() {
// 	console.log( arguments );
// });
